@@ -109,7 +109,7 @@ def run(args):
     include_path_match = IncludePathsMatch()
     include_name_match = IncludeNameMatch()
 
-    return launch_behavex()
+    return launch_behavex(args_parsed)
 
 
 def setup_running_failures(args_parsed):
@@ -136,7 +136,7 @@ def init_multiprocessing():
     signal.signal(signal.SIGINT, signal.SIG_IGN)
 
 
-def launch_behavex():
+def launch_behavex(args):
     """Launch the BehaveX test execution in the specified parallel mode."""
     json_reports = None
     execution_codes = None
@@ -174,6 +174,12 @@ def launch_behavex():
             execution_codes, json_reports = launch_by_feature(
                 features_list, process_pool
             )
+
+        customized_json = get_param('customized_json')
+        if args.customized_json != '':
+            with open(customized_json, 'r') as f:
+                json_reports = json.load(f)
+
         wrap_up_process_pools(process_pool, json_reports, multiprocess, scenario)
         time_end = time.time()
 
@@ -580,6 +586,7 @@ def _set_env_variables(args):
             'TEMP',
             'LOGS',
             'LOGGING_LEVEL',
+            'CUSTOMIZED_JSON'
         ]
     )
 
